@@ -1,8 +1,11 @@
+from io import StringIO
+
 from django.test import TestCase, Client
 from django.contrib.auth import get_user_model
 from django.contrib.auth.models import Permission
 from django.contrib.sites.models import Site
 from django.urls import reverse
+from django.core.management import call_command
 
 from .models import Ticket, Comment, Team, Category, Question, StatusChoices, PriorityChoices, VisibilityChoices, CommentTypeChoices
 from .settings import app_settings
@@ -92,6 +95,33 @@ class ClientTests(TestCase):
         self.assertContains(response, "Open")
 
 
+    def test_dashboard_filter_by_site(self):
+        self.client.force_login(self.student)
+        site = Site.objects.create(domain="site2.com", name="Site 2")
+        Ticket.objects.create(subject="Other site", description="Other site description", user=self.student, category=app_settings.TICKET_CATEGORIES.HELP, site=site)
+        uri = reverse("helpme:dashboard")
+        response = self.client.get(uri)
+
+        self.assertContains(response, "ABC")
+        self.assertNotContains(response, "Other site")
+
+
+    def test_dashboard_superuser(self):
+        """
+        Superuser should be able to see all tickets, including on other sites
+        """
+        
+        self.client.force_login(self.admin)
+
+        site = Site.objects.create(domain="site2.com", name="Site 2")
+        Ticket.objects.create(subject="Other site", description="Other site description", user=self.support, category=app_settings.TICKET_CATEGORIES.HELP, site=site)
+        uri = reverse("helpme_admin:dashboard")
+        response = self.client.get(uri)
+
+        self.assertContains(response, "testuser - ABC")
+        self.assertContains(response, "supportuser - Other site")
+
+
     def test_dashboard_filter_by_status(self):
         active_ticket = Ticket.objects.create(subject="Active ticket", description="Test filter", category=app_settings.TICKET_CATEGORIES.HELP, status=StatusChoices.ACTIVE, user=self.support)
         active_ticket.teams.add(self.support_team)
@@ -266,3 +296,21 @@ class ClientTests(TestCase):
         self.assertEqual(response.redirect_chain, [(reverse("helpme_admin:faq-create"), 302)])
         self.assertContains(response, "What color is the sky?")
         self.assertContains(response, "Blue")
+
+
+class ModuleTests(TestCase):
+    '''
+    Tests to make sure basic elements are not missing from the package
+    '''
+    def test_for_missing_migrations(self):
+        output = StringIO()
+
+        try:
+            call_command('makemigrations', interactive=False, dry_run=True, check=True, stdout=output)
+
+        except SystemExit as e:
+            # The exit code will be 1 when there are no missing migrations
+            try:
+                assert e == '1'
+            except:
+                self.fail("\n\nHey, There are missing migrations!\n\n %s" % output.getvalue())
